@@ -1,4 +1,4 @@
-/* $Id: mppresent-generic.cpp 83687 2013-02-08 12:50:49Z fmehnert $ */
+/* $Id: mppresent-generic.cpp 89632 2013-10-07 21:19:37Z bird $ */
 /** @file
  * IPRT - Multiprocessor, Stubs for the RTMp*Present* API.
  */
@@ -46,6 +46,13 @@ RTDECL(RTCPUID) RTMpGetPresentCount(void)
 RT_EXPORT_SYMBOL(RTMpGetPresentCount);
 
 
+RTDECL(RTCPUID) RTMpGetPresentCoreCount(void)
+{
+    return RTMpGetCoreCount();
+}
+RT_EXPORT_SYMBOL(RTMpGetPresentCoreCount);
+
+
 RTDECL(bool) RTMpIsCpuPresent(RTCPUID idCpu)
 {
     return RTMpIsCpuPossible(idCpu);
